#ifndef NT2_INCLUDE_FUNCTIONS_CAUPDF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CAUPDF_HPP_INCLUDED

#include <nt2/statistics/include/functions/caupdf.hpp>

#endif
